import janda
import json
import requests
import os
import re
import time
from .utils.misc import choose, split_name, get_size, convert_html_to_pdf, project, get_size_folder, nums
from inputimeout import inputimeout, TimeoutOccurred

simply = janda.SimplyHentai()


async def get_sim(id: str = choose().simply):
    initial = time.time()
    data = await simply.get(id)
    parser = json.loads(data)

    title = parser['title']
    title = re.sub(r'[^\w\s]', '', title)
    print(f'Title: {title}')

    img = parser['image']
    print(f'Total image: {len(img)}')

    tags = parser['tags']
    tags = [tag for tag in tags]
    print(f'Tags: {tags}')

    neat_dir = f'{split_name(__file__)}-{title}'
    neat_dir = re.sub('[^A-Za-z0-9-]+', ' ', neat_dir)
  
    neat_dir = re.sub(r'\s+', '_', neat_dir)

    set_name = parser['id']
    ## get value in last slash of set_name
    set_name = set_name.split('/')[-1]

    if not os.path.exists(neat_dir):
        os.makedirs(neat_dir)

    if len(os.listdir(neat_dir)) - 1 == len(img):
        print("All images already downloaded! If you're doubt kindly remove this folder and re-download")
        print(f'Directory: {os.path.abspath(neat_dir)}')
        return

    for i in range(len(img)):
        start = time.time()
        r = requests.get(img[i])
        with open(f"{neat_dir}/{i+1}.jpg", 'wb') as f:
            f.write(r.content)

            if os.path.exists(f"{neat_dir}/{i+1}.jpg"):
                file = get_size(f"{neat_dir}/{i+1}.jpg")
                print(
                    f'Successfully downloaded {i+1} | {file} MB | took {time.time() - start:.2f} seconds')

            if len(img) == len(os.listdir(neat_dir)):

                print(f'Successfully downloaded all images taken {(time.time() - initial) / 60:.2f} minutes with total size {get_size_folder(neat_dir)} MB')
                print(f'Directory: {os.path.abspath(neat_dir)}')
                
                with open(neat_dir + '/tomoe.html', 'x', encoding="utf-8") as f:
                    f.write('<html><center><body>')
                    f.write(f"<h1>{neat_dir}</h1>")

                    for i in nums(1, len(img)):
                        
                        f.write(f'<img src="{neat_dir}/{i}.jpg"><p></p>')
                    f.write(f'{project()}')
                    f.write('</body></center></html>')
                    f.close()

                try:
                    desired = inputimeout(prompt='Do you want to render it all to .pdf? (y/n) ', timeout=10)
                    to_pdf = desired

                    if to_pdf == 'y':
                        try:
                            source = open(f"{neat_dir}/tomoe.html")
                            output = f"{neat_dir}/{set_name}.pdf"
                            filepdf = output.rsplit('/', 1)[-1]

                            convert_html_to_pdf(source, output)
                            print(f'Successfully rendered to {filepdf} | {get_size(output)} MB') 
            
                        except Exception as e:
                            print(f"Something went wrong while converting to pdf: {e}")
                                
                    elif to_pdf == 'n':
                        print("Okay")
                        os.remove(neat_dir + '/tomoe.html')
                        return

                    else:
                        print("Invalid input")
                        os.remove(neat_dir + '/tomoe.html')
                        return

                except TimeoutOccurred:
                    print("Timeout occurred")
                    os.remove(neat_dir + '/tomoe.html')
                    exit()



import janda
import json
import requests
import os
import re
import time
from .utils.misc import choose, split_name, get_size, convert_html_to_pdf, project, get_size_folder
from inputimeout import inputimeout, TimeoutOccurred

hfox = janda.Hentaifox() 


async def get_hfox(id: int = choose().hentaifox):
    initial = time.time()
    data = await hfox.get(id)
    parser = json.loads(data)
    title = parser['title']
    title = re.sub(r'[^\w\s]','', title)
    number = parser['id']
    print(f'Title: {title}')

    img = parser['images']
    print(f'Total image: {len(img)}')
    print(f'Tags: {parser["tags"]}')
    
    neat_dir = f'{split_name(__file__)}-{number}-{title}'
    neat_dir = re.sub('[^A-Za-z0-9-]+', ' ', neat_dir)
  
    neat_dir = re.sub(r'\s+', '_', neat_dir)
    
    if not os.path.exists(neat_dir):
        os.makedirs(neat_dir)

    if len(img) == len(os.listdir(neat_dir)):
        print("All images already downloaded! If you're doubt kindly remove this folder and re-download")
        print(f'Directory: {os.path.abspath(neat_dir)}')
        return

    for i in img:
        start = time.time()
        img_url = i

        try:
            r = requests.get(img_url)
            if r.status_code == 200:
                img_url = img_url
            else:
                img_url = re.sub(r'(?<=\d{3})\d{3}', r.status_code, img_url)
        except:
            img_url = img_url.replace('.jpg', '.png')

        img_name = img_url.rsplit('/', 1)[-1]

        r = requests.get(img_url)
        with open(neat_dir + '/' + img_name, 'wb') as f:
            
            f.write(r.content)
     
            if os.path.exists(neat_dir + '/' + img_name):
                print(f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | took {time.time() - start:.2f} seconds')
            
            if len(img) == len(os.listdir(neat_dir)):
              
                print(f'Successfully downloaded all images taken {(time.time() - initial) / 60:.2f} minutes with total size {get_size_folder(neat_dir)} MB')

                with open(neat_dir + '/tomoe.html', 'x', encoding="utf-8") as f:
                    f.write('<html><center><body>')
                    f.write(f"<h1>{parser['id']}</h1>")
   
                    for i in img:
                        img_url = i
                        try:
                            r = requests.get(img_url)
                            if r.status_code == 200:
                                img_url = img_url
                            else:
                                img_url = re.sub(r'(?<=\d{3})\d{3}', r.status_code, img_url)
                        except:
                            img_url = img_url.replace('.jpg', '.png')
                        ## get after last slash in img, example /1.jpg
                        file = img_url.rsplit('/', 1)[-1]
                        
                        f.write(f'<img src="{neat_dir}/{file}"><p></p>')
                    f.write(f'{project()}')
                    f.write('</body></center></html>')
                    f.close()

                    
                    print(f'Directory: {os.path.abspath(neat_dir)}')

        
                try:
                    desired = inputimeout(prompt='Do you want to render it all to .pdf? (y/n) ', timeout=10)
                    to_pdf = desired

                    if to_pdf == 'y':
                        try:
                            source = open(f"{neat_dir}/tomoe.html")
                            output = f"{neat_dir}/{parser['id']}.pdf"
                            filepdf = output.rsplit('/', 1)[-1]

                            convert_html_to_pdf(source, output)
                            print(f'Successfully rendered to {filepdf} | {get_size(output)} MB') 
            
                        except Exception as e:
                            print(
                                f"Something went wrong while converting to pdf: {e}")
                                
                    elif to_pdf == 'n':
                        print("Okay")
                        os.remove(neat_dir + '/tomoe.html')
                        return

                    else:
                        print("Invalid input")
                        os.remove(neat_dir + '/tomoe.html')
                        return

                except TimeoutOccurred:
                    print("Timeout occurred")
                    os.remove(neat_dir + '/tomoe.html')
                    exit()


import janda
import json
import requests
import os
import re
import time
from .utils.misc import choose, split_name, get_size, convert_html_to_pdf, project
from inputimeout import inputimeout, TimeoutOccurred

nh = janda.Nhentai()


async def get_nh(id: int = choose().nhentai):
    initial = time.time()
    data = await nh.get(id)
    parser = json.loads(data)

    title = parser['details']['title']['pretty']
    title = re.sub(r'[^\w\s]', '', title)
    number = parser['details']['id']
    print(f'Title: {title}')

    img = parser['image_urls']
    print(f'Total: {len(img)}')

    tags = parser['tags']
    ## jadikan satu variable dari tags list
    tags = [tag for tag in tags]
    print(f'Tags: {tags}')

    neat_dir = f'{split_name(__file__)}-{number}-{title}'
    neat_dir = re.sub('[^A-Za-z0-9-]+', ' ', neat_dir)
  
    neat_dir = re.sub(r'\s+', '_', neat_dir)

    if not os.path.exists(neat_dir):
        os.makedirs(neat_dir, 0o700)

    if len(os.listdir(neat_dir)) >= len(img):
        print("All images already downloaded! If you're doubt kindly remove this folder and re-download")
        print(f'Directory: {os.path.abspath(neat_dir)}')
        return

    for i in img:
        start = time.time()
        img_url = i
        img_name = img_url.rsplit('/', 1)[-1]

        r = requests.get(img_url)
        with open(neat_dir + '/' + img_name, 'wb') as f:
            f.write(r.content)

            if os.path.exists(neat_dir + '/' + img_name):
                print(
                    f'Successfully downloaded {img_name} | {get_size(neat_dir + "/" + img_name)} MB | took {time.time() - start:.2f} seconds')

            if len(img) == len(os.listdir(neat_dir)):
                print(
                    f'Successfully downloaded all images in {(time.time() - initial) / 60:.2f} minutes')
                with open(neat_dir + '/tomoe.html', 'x', encoding="utf-8") as f:
                    f.write('<html><center><body>')
                    f.write(f"<h1>{parser['details']['id']}</h1>")
   
                    for i in img:
                        ## get after last slash in img, example /1.jpg
                        file = i.rsplit('/', 1)[-1]
                        ## print(file)
                        
                        f.write(f'<img src="{neat_dir}/{file}"><p></p>')
                    f.write(f'{project()}')
                    f.write('</body></center></html>')
                    f.close()

                    
                    print(f'Directory: {os.path.abspath(neat_dir)}')

        
                try:
                    desired = inputimeout(prompt='Do you want to render it all to .pdf? (y/n) ', timeout=10)
                    to_pdf = desired

                    if to_pdf == 'y':
                        try:
                            source = open(f"{neat_dir}/tomoe.html")
                            output = f"{neat_dir}/{parser['details']['id']}.pdf"

                            convert_html_to_pdf(source, output)
                            print(f'Successfully converted to {output}')  
            
                        except Exception as e:
                            print(
                                f"Something went wrong while converting to pdf: {e}")
                                
                    elif to_pdf == 'n':
                        print("Okay")
                        os.remove(neat_dir + '/tomoe.html')
                        return

                    else:
                        print("Invalid input")
                        os.remove(neat_dir + '/tomoe.html')
                        return

                except TimeoutOccurred:
                    print("Timeout occurred")
                    os.remove(neat_dir + '/tomoe.html')
                    exit()




import argparse
import os
from xhtml2pdf import pisa

def choose():
    my_parser = argparse.ArgumentParser()

    my_parser.add_argument('--nhentai', action='store', type=int)
    my_parser.add_argument('--pururin', action='store', type=int)
    my_parser.add_argument('--simply', action='store', type=str)
    my_parser.add_argument('--hentaifox', action='store', type=int)
    my_parser.add_argument('--hentai2read', nargs=2)

    
    args = my_parser.parse_args()
    return args

def split_name(string):
    get_name = os.path.basename(string).split('.')[0]
    return get_name

def get_size(string):
    file = round(os.path.getsize(string) / 1024 / 1024, 2)
    return file

## create function get_size folder in MB
def get_size_folder(folder):
    total_size = 0
    for dirpath, dirnames, filenames in os.walk(folder):
        for f in filenames:
            fp = os.path.join(dirpath, f)
            total_size += os.path.getsize(fp)
    return round(total_size / 1024 / 1024, 2)

def project():
    return '<p><b><h1><a href="https://pypi.org/project/tomoe/">Generated from tomoe: https://pypi.org/project/tomoe</a></b><h1>'
           
def convert_html_to_pdf(source_html, output_filename):
    # open output file for writing (truncated binary)
    result_file = open(output_filename, "w+b")

    # convert HTML to PDF
    pisa_status = pisa.CreatePDF(
            source_html,                # the HTML to convert
            dest=result_file)           # file handle to recieve result

    # make the result is scrollable
    pisa_status.dest.seek(0)
    

    # close output file
    result_file.close()                 # close output file

    # return False on success and True on errors
    return pisa_status.err

def nums(first_number, last_number, step=1):
    return range(first_number, last_number+1, step)